@@ -1,16 +1,16 @@
 import pytest
-from pyrosm import get_path
+from pyrosm import get_data
 
 
 @pytest.fixture
 def test_pbf():
-    pbf_path = get_path("test_pbf")
+    pbf_path = get_data("test_pbf")
     return pbf_path
 
 
 @pytest.fixture
 def helsinki_pbf():
-    pbf_path = get_path("helsinki_pbf")
+    pbf_path = get_data("helsinki_pbf")
     return pbf_path
 
 
@@ -49,7 +49,8 @@ def test_parsing_pois_with_defaults(helsinki_pbf, default_filter):
                        osm._way_records,
                        osm._relations,
                        tags_as_columns,
-                       default_filter)
+                       default_filter,
+                       None)
 
     assert isinstance(gdf, GeoDataFrame)
 
@@ -59,7 +60,7 @@ def test_parsing_pois_with_defaults(helsinki_pbf, default_filter):
         assert col in gdf.columns
 
     # Test shape
-    assert len(gdf) == 1780
+    assert len(gdf) == 1782
     assert gdf.crs == pyproj.CRS.from_epsg(4326)
 
 
@@ -79,9 +80,8 @@ def test_reading_pois_from_area_having_none(helsinki_pbf):
         if "could not find any buildings" in str(w):
             pass
 
-    # Result should be empty GeoDataFrame
-    assert isinstance(gdf, GeoDataFrame)
-    assert gdf.shape == (0, 0)
+    # Result should be None
+    assert gdf is None
 
 
 def test_passing_incorrect_custom_filter(test_pbf):
@@ -94,4 +94,42 @@ def test_passing_incorrect_custom_filter(test_pbf):
         if "dictionary" in str(e):
             pass
     except Exception as e:
-        raise e
\ No newline at end of file
+        raise e
+
+
+def test_adding_extra_attribute(helsinki_pbf):
+    from pyrosm import OSM
+    from geopandas import GeoDataFrame
+
+    osm = OSM(filepath=helsinki_pbf)
+    gdf = osm.get_pois()
+    extra_col = "wikidata"
+    extra = osm.get_pois(extra_attributes=[extra_col])
+
+    # The extra should have one additional column compared to the original one
+    assert extra.shape[1] == gdf.shape[1]+1
+    # Should have same number of rows
+    assert extra.shape[0] == gdf.shape[0]
+    assert extra_col in extra.columns
+    assert len(extra[extra_col].dropna().unique()) > 0
+    assert isinstance(gdf, GeoDataFrame)
+
+
+def test_using_multiple_filters(helsinki_pbf):
+    from pyrosm import OSM
+    from geopandas import GeoDataFrame
+
+    osm = OSM(filepath=helsinki_pbf)
+    gdf = osm.get_pois({"shop": ["alcohol"], "amenity": ["pub"]})
+
+    # shop and amenity columns should only contain alcohol and pub as requested
+    # (in addition to None values)
+    shop = gdf["shop"].unique().tolist()
+    shop = [item for item in shop if isinstance(item, str)]
+    amenity = gdf["amenity"].unique().tolist()
+    amenity = [item for item in amenity if isinstance(item, str)]
+
+    assert isinstance(gdf, GeoDataFrame)
+    assert shop == ["alcohol"]
+    assert amenity == ["pub"]
+    assert gdf.shape == (59, 32)
